import sqlite3
from typing import List, Dict

class AreaLoader:
    def __init__(self, db_path):
        self.conn = sqlite3.connect(db_path)
        self.cursor = self.conn.cursor()

    def get_area_details(self, pattern: str) -> List[Dict]:
        try:
            sql_pattern = pattern.replace('*', '%')
            self.cursor.execute(
                "SELECT id, name FROM areas WHERE id LIKE ?",
                (sql_pattern,)
            )
            return [{"code": row[0], "name": row[1]} for row in self.cursor.fetchall()]
        except sqlite3.Error as e:
            return []
    
    def get_possible_areas(self, code_pattern: str) -> List:
        fixed_pattern = code_pattern.ljust(6, '*')
        sql_pattern = fixed_pattern.replace('*', '%')[:6]
        try:
            self.cursor.execute(
                "SELECT id, name FROM areas WHERE id LIKE ? AND LENGTH(id) = 6 ORDER BY id",
                (sql_pattern,)
            )
            return self.cursor.fetchall()
        except sqlite3.Error as e:
            print(f"Database error: {e}")
            return []

    def close(self):
        self.conn.close()

if __name__ == '__main__':
    loader = AreaLoader('DB/area_format.db')
    for pattern in ["1101*1"]:
        print(f"\n模式 {pattern} →")
        print(loader.get_possible_areas(pattern))
    loader.close()