from datetime import datetime
from typing import List
import re

class DateGenerator:
    @staticmethod
    def generate_dates(pattern: str) -> List[str]:
        if len(pattern) != 8 or not re.match(r"^[\d*]{8}$", pattern):
            return []

        def expand_part(part: str) -> List[str]:
            wildcards = part.count('*')
            if wildcards == 0: 
                return [part] if part.isdigit() else []
            results = []
            for n in range(10**wildcards):
                digits = f"{n:0{wildcards}d}"
                temp = list(part)
                idx = 0
                for i in range(len(temp)):
                    if temp[i] == '*':
                        if idx >= len(digits): break
                        temp[i] = digits[idx]
                        idx += 1
                results.append(''.join(temp))
            return [r for r in results if r.isdigit()]

        candidates = []
        current_year = datetime.now().year
        
        years = expand_part(pattern[:4])
        months = expand_part(pattern[4:6])
        days = expand_part(pattern[6:8])

        for y in years:
            if not 1900 <= int(y) <= current_year:
                continue
            for m in months:
                if not 1 <= int(m) <= 12:
                    continue
                for d in days:
                    if not 1 <= int(d) <= 31:
                        continue
                    try:
                        date_str = f"{y}{m}{d}"
                        datetime.strptime(date_str, "%Y%m%d")
                        candidates.append(date_str)
                    except:
                        pass
        return sorted(list(set(candidates)))

if __name__ == "__main__":
    print(DateGenerator.generate_dates('199010**'))